aboutsummaryrefslogtreecommitdiffstats
path: root/CompilerContext.h
diff options
context:
space:
mode:
Diffstat (limited to 'CompilerContext.h')
-rw-r--r--CompilerContext.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/CompilerContext.h b/CompilerContext.h
index cde992d5..d82dfe51 100644
--- a/CompilerContext.h
+++ b/CompilerContext.h
@@ -42,9 +42,11 @@ public:
void addMagicGlobal(MagicVariableDeclaration const& _declaration);
void addStateVariable(VariableDeclaration const& _declaration);
void startNewFunction() { m_localVariables.clear(); m_asm.setDeposit(0); }
- void addVariable(VariableDeclaration const& _declaration);
+ void addVariable(VariableDeclaration const& _declaration, unsigned _offsetToCurrent = 0);
void addAndInitializeVariable(VariableDeclaration const& _declaration);
void addFunction(FunctionDefinition const& _function);
+ /// Adds the given modifier to the list by name if the name is not present already.
+ void addModifier(ModifierDefinition const& _modifier);
void setCompiledContracts(std::map<ContractDefinition const*, bytes const*> const& _contracts) { m_compiledContracts = _contracts; }
bytes const& getCompiledContract(ContractDefinition const& _contract) const;
@@ -59,7 +61,8 @@ public:
eth::AssemblyItem getFunctionEntryLabel(FunctionDefinition const& _function) const;
/// @returns the entry label of the given function and takes overrides into account.
eth::AssemblyItem getVirtualFunctionEntryLabel(FunctionDefinition const& _function) const;
- /// Returns the distance of the given local variable from the top of the local variable stack.
+ ModifierDefinition const& getFunctionModifier(std::string const& _name) const;
+ /// Returns the distance of the given local variable from the bottom of the stack (of the current function).
unsigned getBaseStackOffsetOfVariable(Declaration const& _declaration) const;
/// If supplied by a value returned by @ref getBaseStackOffsetOfVariable(variable), returns
/// the distance of that variable from the current top of the stack.
@@ -112,14 +115,14 @@ private:
u256 m_stateVariablesSize = 0;
/// Storage offsets of state variables
std::map<Declaration const*, u256> m_stateVariables;
- /// Offsets of local variables on the stack (relative to stack base).
+ /// Positions of local variables on the stack.
std::map<Declaration const*, unsigned> m_localVariables;
- /// Sum of stack sizes of local variables
- unsigned m_localVariablesSize;
/// Labels pointing to the entry points of funcitons.
std::map<Declaration const*, eth::AssemblyItem> m_functionEntryLabels;
/// Labels pointing to the entry points of function overrides.
std::map<std::string, eth::AssemblyItem> m_virtualFunctionEntryLabels;
+ /// Mapping to obtain function modifiers by name. Should be filled from derived to base.
+ std::map<std::string, ModifierDefinition const*> m_functionModifiers;
};
}